@@ -23,6 +23,8 @@
  *          Kristian Rietveld <kris@gtk.org>
  */
 
+#include "config.h"
+
 #include <glade/glade.h>
 #include <string.h>
 #include <stdlib.h>
@@ -339,7 +341,7 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
   text = glade_xml_get_widget (glade_dialog, "zenity_tree_text");
                                                                                 
   if (tree_data->dialog_text)
-    gtk_label_set_text (GTK_LABEL (text), tree_data->dialog_text);
+    gtk_label_set_markup (GTK_LABEL (text), g_strcompress (tree_data->dialog_text));
 
   zenity_util_set_window_icon (dialog, data->window_icon, ZENITY_IMAGE_FULLPATH ("zenity-list.png"));
 
@@ -527,7 +529,7 @@ static gboolean
 zenity_tree_dialog_toggle_get_selected (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, GtkTreeView *tree_view)
 {
   GValue toggle_value = {0, };
-  gint n_columns, print_column, i;
+  gint n_columns, i;
 
   n_columns = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (tree_view), "n_columns"));
 
@@ -669,7 +671,7 @@ zenity_tree_extract_column_indexes (char *indexes, int n_columns)
     if (index > 0 && index <= n_columns) {
       result[j] = index;
       j++;
-      g_renew (gint, result, j + 1);
+      result = g_renew (gint, result, j + 1);
     }
   }
   result[j] = 0;
